@@ -3,7 +3,7 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-/* FIXME: 
+/* FIXME:
    Check these declarations against the C/Fortran source code.
 */
 
@@ -11,8 +11,12 @@
 extern SEXP _foreSIGHT_latentX_calc_cpp(SEXP, SEXP, SEXP);
 extern SEXP _foreSIGHT_Pstatus_WGEN_cpp(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _foreSIGHT_residualGenerator_cpp(SEXP, SEXP);
+extern SEXP _foreSIGHT_doyMean_cpp(SEXP, SEXP);
+extern SEXP _foreSIGHT_calc_mean_day_clim_cpp(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
+    {"_foreSIGHT_calc_mean_day_clim_cpp",      (DL_FUNC) &_foreSIGHT_calc_mean_day_clim_cpp,      2},
+    {"_foreSIGHT_doyMean_cpp",      (DL_FUNC) &_foreSIGHT_doyMean_cpp,      2},
     {"_foreSIGHT_latentX_calc_cpp",      (DL_FUNC) &_foreSIGHT_latentX_calc_cpp,      3},
     {"_foreSIGHT_Pstatus_WGEN_cpp",      (DL_FUNC) &_foreSIGHT_Pstatus_WGEN_cpp,      4},
     {"_foreSIGHT_residualGenerator_cpp", (DL_FUNC) &_foreSIGHT_residualGenerator_cpp, 2},
